# coding: utf-8
'''
CREATE MATERIALIZED VIEW

Optimizes read requests by allowing different partitioning and clustering columns than the base table and eliminates the need for individual write requests to multiple tables. When data is written to the base table, it is also automatically written to all associated materialized views.

**Restriction:**

-   Use all base table primary keys in the materialized view.
-   Optionally, add one non-PRIMARY KEY column from the base table to the materialized view's PRIMARY KEY.
-   Static columns are not supported as a PRIMARY KEY.

Synopsis


CREATE MATERIALIZED VIEW [ IF NOT EXISTS ] [keyspace_name.]view_name
  AS SELECT [ (column_list) ]
  FROM [keyspace_name.]table_name
  WHERE column_name IS NOT NULL [ AND column_name IS NOT NULL ... ]
    [ AND relation [ AND ... ] ] 
  PRIMARY KEY (column_list)
  [ WITH [ table_properties ]
    [ [ AND ] CLUSTERING ORDER BY (cluster_column_name order_option) ] ] ;


IF NOT EXISTS
    Optional. Suppresses the error message when attempting to create a materialized view that already exists. Use to continue executing commands, such as a `SOURCE` command. The option only validates that a materialized view with the same name exists; columns, primary keys, properties and other settings can differ.

keyspace_name
    Optional. When no keyspace is selected or to create the view in another keyspace, enter keyspace name before the materialized view name.

    **Note:** Base tables and materialized views are always in the same keyspace.

view_name
    Materialized view names can only contain alpha-numeric characters and underscores. The view name must begin with a number or letter and can be up to 49 characters long.

column_list
    Comma-separated list of non-PRIMARY KEY columns from the base table to include in the materialized view. All primary key columns are automatically included.

    Static columns, even when specified, are not included in the materialized view.

PK_column_name IS NOT NULL
    Test all primary key columns for null values in the where clause. Separate each condition with `AND`. Rows with null values in the primary key are not inserted into the materialized view table.

AND relation
    Other relations that target the specific data needed.

PRIMARY KEY (column_list)
    Comma-separated list of columns used to partition and cluster the data. You can add a single non-primary key column from the base table. Reorder the primary keys as needed to query the table more efficiently, including changing the partitioning and clustering keys.

table_properties
    Optional. Specify table properties if different than default. Separate table property definitions with an AND.

    **Note:** The base table properties are not copied.

    **Restriction:** Change log, CDC, is not available for materialized views.


'''
